﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
//using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Collections.ObjectModel;

//-------------------------------------------------------
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace WPFTestInteractiveLayer
{
    /// <summary>
    /// Interaction logic for TestWindow.xaml
    /// </summary>
    public partial class TestWindow : Window
    {

        InMemoryFeatureLayer _objCircleLayer;
        LayerOverlay _objLayerOverlay;
        public TestWindow()
        {
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;
            wpfMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

            wpfMap1.CurrentExtent = new RectangleShape(-118.2957, 38.9791, -115.2397, 34.9452);
            wpfMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.FromArgb(255, 198, 255, 255));

            //Displays the World Map Kit as a background.
            WorldMapKitWmsWpfOverlay worldOverlay = new WorldMapKitWmsWpfOverlay();
            wpfMap1.Overlays.Add(worldOverlay);

            FileBitmapTileCache bitmapTileCache = new FileBitmapTileCache();
            bitmapTileCache.CacheDirectory = @"C:\temp";
            bitmapTileCache.CacheId = "WorldMapKitWmsWpfTiles";
            bitmapTileCache.TileAccessMode = TileAccessMode.ReadAddDelete;
            bitmapTileCache.ImageFormat = TileImageFormat.Png;
            worldOverlay.TileCache = bitmapTileCache;
            // Defining Custom Track Overlay to define Polygons
            CircleTrackInteractiveOverlay CircleTrackInteractiveOverlay = new CircleTrackInteractiveOverlay();
            wpfMap1.TrackOverlay = CircleTrackInteractiveOverlay;

            wpfMap1.TrackOverlay.TrackEnded += new EventHandler<TrackEndedTrackInteractiveOverlayEventArgs>(_TrackMapEnded);

            _objLayerOverlay = new LayerOverlay();

            _objCircleLayer = new InMemoryFeatureLayer();
            /*
            _objCircleLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle(LayerColNames._FeatureID,
                          "Arial", 10, DrawingFontStyles.Regular, GeoColor.StandardColors.Red, 0, -12);

            _objCircleLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.BestPlacement = true;
            _objCircleLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
             */
            _objCircleLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            GeoLinearGradientBrush geoBrush = null;
            GeoColor stColor = GeoColor.FromArgb(100, GeoColor.StandardColors.Green);
            GeoColor endColor = GeoColor.FromArgb(10,GeoColor.StandardColors.LightSeaGreen);
            geoBrush = new GeoLinearGradientBrush(stColor, 
                     endColor,
                   GeoLinearGradientDirection.UpperLeftToLowerRight);

            _objCircleLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.Advanced.FillCustomBrush = geoBrush;


            _objCircleLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.Color = GeoColor.StandardColors.DarkGreen;
            _objCircleLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle.OuterPen = new GeoPen(GeoColor.FromArgb(200, GeoColor.StandardColors.Red), 5);
            _objCircleLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.SymbolPen = new GeoPen(GeoColor.FromArgb(255, GeoColor.StandardColors.Green), 8);
            _objCircleLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            _objLayerOverlay.Layers.Add("MyCircleLayer", _objCircleLayer);

            wpfMap1.Overlays.Add("MyOverlay", _objLayerOverlay);


              
            wpfMap1.Refresh();
            
        }

        private void btnCreateCircle_Click(object sender, RoutedEventArgs e)
        {
         
        }


        private void btnEditCircle_Click(object sender, RoutedEventArgs e)
        {
         
        }

        private void _TrackMapEnded(object sender,
         TrackEndedTrackInteractiveOverlayEventArgs e)
        {
            BaseShape baseShape = wpfMap1.TrackOverlay.GetTrackingShape();

            EllipseShape ellipseShape = baseShape as EllipseShape;
            if (null == ellipseShape) // Issue: This is supposed to be  Ellipse !!!!
            {
            
              System.Windows.MessageBox.Show("Shape is not a Ellipse:", "Error?");              

            }
            foreach (Feature feature in wpfMap1.TrackOverlay.TrackShapeLayer.InternalFeatures)
            {
               _objCircleLayer.InternalFeatures.Add(feature);
            }
            wpfMap1.TrackOverlay.TrackShapeLayer.InternalFeatures.Clear();
            wpfMap1.Refresh(new Overlay[] { wpfMap1.TrackOverlay, _objLayerOverlay });
          
        }
        
    }

}
